@@ -13,10 +13,9 @@ DOCUMENTATION_FILE = f'{KW_OPEN_API}{c.DOT}{KW_JSON}'
 def getDocumentationFolderPath(apiInstance):
     globals = apiInstance.globals
     return f'{globals.currentPath}{KW_API}{globals.OS_SEPARATOR}{KW_RESOURCE}{globals.OS_SEPARATOR}{KW_OPEN_API}{KW_UI}'
-    # return f'{apiInstance.documentationFolder}{g.OS_SEPARATOR}{DOCUMENTATION_FILE}'
 
 def getDocumentationFilePath(apiInstance):
-    # return f'{g.apiPath}api{g.OS_SEPARATOR}resource{g.OS_SEPARATOR}swaggerui{g.OS_SEPARATOR}swagger.json'
+    globals = apiInstance.globals
     return f'{getDocumentationFolderPath(apiInstance)}{globals.OS_SEPARATOR}{DOCUMENTATION_FILE}'
 
 def loadDocumentationAsString(apiInstance):
